==> libreoffice-fresh-sdk-24.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextSection.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextSection =
[
    [ "TextContent", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a396dbb986854d715acfbe39a9c78b395", null ],
    [ "UserDefinedAttributesSupplier", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aa45a411ca57701213624a7c07e4c2da7", null ],
    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "XPropertyState", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ab92854f223b524caa5a846cd817f9ee7", null ],
    [ "XNamed", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a06d9bde12d6408506b7a64e0e0d1408a", null ],
    [ "XTextSection", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a196428102ed109cd8f285e1c8608ccca", null ],
    [ "BackGraphic", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a693b9e884e9ada31d9657de3f9476eef", null ],
    [ "BackGraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ad6e49dda9aa792372fdd52385d04aa4f", null ],
    [ "BackGraphicLocation", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a229455fd0417732944f850139fdf96d5", null ],
    [ "BackGraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a6b97d77257452a59e2cb997be9e04eca", null ],
    [ "Condition", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a31bc56c8f7574bfe13fe6ed8cc454e54", null ],
    [ "DDECommandElement", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a28ac5c6791eb9c1fd92d130c6d8840bd", null ],
    [ "DDECommandFile", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ae614d4e217fdd8bf15a1d69830f08695", null ],
    [ "DDECommandType", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a81bd32b6cbdb54b70cfac2f14ed1f76d", null ],
    [ "EndnoteIsCollectAtTextEnd", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#afcda2f26d4ed198b48a0f3579f597495", null ],
    [ "EndnoteIsOwnNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a47ffeacea43f98c903e12469db30906a", null ],
    [ "EndnoteIsRestartNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a70a8ee89bc02921f289ee166d76355b2", null ],
    [ "EndnoteNumberingPrefix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ab4080c697442c7161b84516b7c377e77", null ],
    [ "EndnoteNumberingSuffix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a796318dbf723b454edd3a6cccdc15468", null ],
    [ "EndnoteNumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aeb5e897d7dcbab6067f3d25872147a78", null ],
    [ "EndnoteRestartNumberingAt", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a87c18a1f0bfe3d57a6384bef61f0bd23", null ],
    [ "FileLink", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#abfa2b11ef5ea558eee46e6f87d26d1dc", null ],
    [ "FootnoteIsCollectAtTextEnd", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a346f7f734f85a6f06ef3388d4f4465cf", null ],
    [ "FootnoteIsOwnNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#adaf9b1279a2d1102c855ae6644e2b7f1", null ],
    [ "FootnoteIsRestartNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ac7d22dfc4ac6e9018bf6584fccf40994", null ],
    [ "FootnoteNumberingPrefix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#abc0ed0ac1a938a026077e35f290bd021", null ],
    [ "FootnoteNumberingSuffix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a4c9c2fcf8f372b24a60051596c0e9092", null ],
    [ "FootnoteNumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a81da8ce07d00c5cb33c98d55f7b151d0", null ],
    [ "FootnoteRestartNumberingAt", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a34d17179a91c032f67c6bb557c079559", null ],
    [ "IsAutomaticUpdate", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aa2df073f9e224c9db48e30979ab05e22", null ],
    [ "IsProtected", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aaad2943237579803626aa6f3cde07295", null ],
    [ "IsVisible", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a9a886e02e55d4f1dbabbb84da0ae7e7f", null ],
    [ "LinkRegion", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a91f6678e4ecdb784286fe9a91abe730a", null ],
    [ "SectionLeftMargin", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a14c0f380c57819d11b8d50c5837589d6", null ],
    [ "SectionRightMargin", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a55f6aa4c23048dc99f533fd84d225ce9", null ],
    [ "TextColumns", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ac721260998fef025f90f77f3ef3f04bb", null ]
];

==> libreoffice-fresh-sdk-25.8.3-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextSection.js <==
var servicecom_1_1sun_1_1star_1_1text_1_1TextSection =
[
    [ "com::sun::star::text::TextContent", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a396dbb986854d715acfbe39a9c78b395", null ],
    [ "com::sun::star::xml::UserDefinedAttributesSupplier", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aa45a411ca57701213624a7c07e4c2da7", null ],
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::beans::XPropertyState", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ab92854f223b524caa5a846cd817f9ee7", null ],
    [ "com::sun::star::container::XNamed", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a06d9bde12d6408506b7a64e0e0d1408a", null ],
    [ "com::sun::star::text::XTextSection", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a196428102ed109cd8f285e1c8608ccca", null ],
    [ "BackGraphic", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a693b9e884e9ada31d9657de3f9476eef", null ],
    [ "BackGraphicFilter", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ad6e49dda9aa792372fdd52385d04aa4f", null ],
    [ "BackGraphicLocation", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a229455fd0417732944f850139fdf96d5", null ],
    [ "BackGraphicURL", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a6b97d77257452a59e2cb997be9e04eca", null ],
    [ "Condition", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a31bc56c8f7574bfe13fe6ed8cc454e54", null ],
    [ "DDECommandElement", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a28ac5c6791eb9c1fd92d130c6d8840bd", null ],
    [ "DDECommandFile", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ae614d4e217fdd8bf15a1d69830f08695", null ],
    [ "DDECommandType", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a81bd32b6cbdb54b70cfac2f14ed1f76d", null ],
    [ "EndnoteIsCollectAtTextEnd", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#afcda2f26d4ed198b48a0f3579f597495", null ],
    [ "EndnoteIsOwnNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a47ffeacea43f98c903e12469db30906a", null ],
    [ "EndnoteIsRestartNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a70a8ee89bc02921f289ee166d76355b2", null ],
    [ "EndnoteNumberingPrefix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ab4080c697442c7161b84516b7c377e77", null ],
    [ "EndnoteNumberingSuffix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a796318dbf723b454edd3a6cccdc15468", null ],
    [ "EndnoteNumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aeb5e897d7dcbab6067f3d25872147a78", null ],
    [ "EndnoteRestartNumberingAt", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a87c18a1f0bfe3d57a6384bef61f0bd23", null ],
    [ "FileLink", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#abfa2b11ef5ea558eee46e6f87d26d1dc", null ],
    [ "FootnoteIsCollectAtTextEnd", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a346f7f734f85a6f06ef3388d4f4465cf", null ],
    [ "FootnoteIsOwnNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#adaf9b1279a2d1102c855ae6644e2b7f1", null ],
    [ "FootnoteIsRestartNumbering", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ac7d22dfc4ac6e9018bf6584fccf40994", null ],
    [ "FootnoteNumberingPrefix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#abc0ed0ac1a938a026077e35f290bd021", null ],
    [ "FootnoteNumberingSuffix", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a4c9c2fcf8f372b24a60051596c0e9092", null ],
    [ "FootnoteNumberingType", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a81da8ce07d00c5cb33c98d55f7b151d0", null ],
    [ "FootnoteRestartNumberingAt", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a34d17179a91c032f67c6bb557c079559", null ],
    [ "IsAutomaticUpdate", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aa2df073f9e224c9db48e30979ab05e22", null ],
    [ "IsProtected", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#aaad2943237579803626aa6f3cde07295", null ],
    [ "IsVisible", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a9a886e02e55d4f1dbabbb84da0ae7e7f", null ],
    [ "LinkRegion", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a91f6678e4ecdb784286fe9a91abe730a", null ],
    [ "SectionLeftMargin", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a14c0f380c57819d11b8d50c5837589d6", null ],
    [ "SectionRightMargin", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#a55f6aa4c23048dc99f533fd84d225ce9", null ],
    [ "TextColumns", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html#ac721260998fef025f90f77f3ef3f04bb", null ]
];
